==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkCharArray.java <==
// java wrapper for vtkCharArray object
//

package vtk;
import vtk.*;

public class vtkCharArray extends vtkDataArray
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataType_2();
  public int GetDataType()
    { return GetDataType_2(); }

  private native void GetTypedTuple_3(int id0,String id1);
  public void GetTypedTuple(int id0,String id1)
    { GetTypedTuple_3(id0,id1); }

  private native void SetTypedTuple_4(int id0,String id1);
  public void SetTypedTuple(int id0,String id1)
    { SetTypedTuple_4(id0,id1); }

  private native void InsertTypedTuple_5(int id0,String id1);
  public void InsertTypedTuple(int id0,String id1)
    { InsertTypedTuple_5(id0,id1); }

  private native int InsertNextTypedTuple_6(String id0);
  public int InsertNextTypedTuple(String id0)
    { return InsertNextTypedTuple_6(id0); }

  private native char GetValue_7(int id0);
  public char GetValue(int id0)
    { return GetValue_7(id0); }

  private native void SetValue_8(int id0,char id1);
  public void SetValue(int id0,char id1)
    { SetValue_8(id0,id1); }

  private native void SetNumberOfValues_9(int id0);
  public void SetNumberOfValues(int id0)
    { SetNumberOfValues_9(id0); }

  private native void InsertValue_10(int id0,char id1);
  public void InsertValue(int id0,char id1)
    { InsertValue_10(id0,id1); }

  private native int InsertNextValue_11(char id0);
  public int InsertNextValue(char id0)
    { return InsertNextValue_11(id0); }

  private native String GetValueRange_12(int id0);
  public String GetValueRange(int id0)
    { return GetValueRange_12(id0); }

  private native String GetValueRange_13();
  public String GetValueRange()
    { return GetValueRange_13(); }

  private native String WritePointer_14(int id0,int id1);
  public String WritePointer(int id0,int id1)
    { return WritePointer_14(id0,id1); }

  private native String GetPointer_15(int id0);
  public String GetPointer(int id0)
    { return GetPointer_15(id0); }

  private native long FastDownCast_16(vtkAbstractArray id0);
  public vtkCharArray FastDownCast(vtkAbstractArray id0) {
    long temp = FastDownCast_16(id0);

    if (temp == 0) return null;
    return (vtkCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native char GetDataTypeValueMin_17();
  public char GetDataTypeValueMin()
    { return GetDataTypeValueMin_17(); }

  private native char GetDataTypeValueMax_18();
  public char GetDataTypeValueMax()
    { return GetDataTypeValueMax_18(); }

  private native char[] GetJavaArray_0();
  public char[] GetJavaArray()
    { return GetJavaArray_0(); }

  private native void SetJavaArray_0(char[] arr);
  public void SetJavaArray(char[] arr)
    { SetJavaArray_0(arr); }

  public vtkCharArray() { super(); }

  public vtkCharArray(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkCharArray.java <==
// java wrapper for vtkCharArray object
//

package vtk;
import vtk.*;

public class vtkCharArray extends vtkDataArray
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataType_2();
  public int GetDataType()
    { return GetDataType_2(); }

  private native void GetTypedTuple_3(int id0,String id1);
  public void GetTypedTuple(int id0,String id1)
    { GetTypedTuple_3(id0,id1); }

  private native void SetTypedTuple_4(int id0,String id1);
  public void SetTypedTuple(int id0,String id1)
    { SetTypedTuple_4(id0,id1); }

  private native void InsertTypedTuple_5(int id0,String id1);
  public void InsertTypedTuple(int id0,String id1)
    { InsertTypedTuple_5(id0,id1); }

  private native int InsertNextTypedTuple_6(String id0);
  public int InsertNextTypedTuple(String id0)
    { return InsertNextTypedTuple_6(id0); }

  private native char GetValue_7(int id0);
  public char GetValue(int id0)
    { return GetValue_7(id0); }

  private native void SetValue_8(int id0,char id1);
  public void SetValue(int id0,char id1)
    { SetValue_8(id0,id1); }

  private native void SetNumberOfValues_9(int id0);
  public void SetNumberOfValues(int id0)
    { SetNumberOfValues_9(id0); }

  private native void InsertValue_10(int id0,char id1);
  public void InsertValue(int id0,char id1)
    { InsertValue_10(id0,id1); }

  private native int InsertNextValue_11(char id0);
  public int InsertNextValue(char id0)
    { return InsertNextValue_11(id0); }

  private native String GetValueRange_12(int id0);
  public String GetValueRange(int id0)
    { return GetValueRange_12(id0); }

  private native String GetValueRange_13();
  public String GetValueRange()
    { return GetValueRange_13(); }

  private native String WritePointer_14(int id0,int id1);
  public String WritePointer(int id0,int id1)
    { return WritePointer_14(id0,id1); }

  private native String GetPointer_15(int id0);
  public String GetPointer(int id0)
    { return GetPointer_15(id0); }

  private native long FastDownCast_16(vtkAbstractArray id0);
  public vtkCharArray FastDownCast(vtkAbstractArray id0) {
    long temp = FastDownCast_16(id0);

    if (temp == 0) return null;
    return (vtkCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native char GetDataTypeValueMin_17();
  public char GetDataTypeValueMin()
    { return GetDataTypeValueMin_17(); }

  private native char GetDataTypeValueMax_18();
  public char GetDataTypeValueMax()
    { return GetDataTypeValueMax_18(); }

  private native char[] GetJavaArray_0();
  public char[] GetJavaArray()
    { return GetJavaArray_0(); }

  private native void SetJavaArray_0(char[] arr);
  public void SetJavaArray(char[] arr)
    { SetJavaArray_0(arr); }

  public vtkCharArray() { super(); }

  public vtkCharArray(long id) { super(id); }
  public native long   VTKInit();

}
